/*
 ThermostatQA - test framework for Thermostat Monitoring Tool

 Copyright 2015 Red Hat, Inc.

 This file is part of ThermostatQA

 ThermostatQA is distributed under the GNU General Public License,
 version 2 or any later version (with a special exception described
 below, commonly known as the "Classpath Exception").

 A copy of GNU General Public License (GPL) is included in this
 distribution, in the file COPYING.

 Linking ThermostatQA code with other modules is making a combined work
 based on ThermostatQA.  Thus, the terms and conditions of the GPL
 cover the whole combination.

 As a special exception, the copyright holders of ThermostatQA give you
 permission to link this code with independent modules to produce an
 executable, regardless of the license terms of these independent
 modules, and to copy and distribute the resulting executable under
 terms of your choice, provided that you also meet, for each linked
 independent module, the terms and conditions of the license of that
 module.  An independent module is a module which is not derived from
 or based on ThermostatQA code.  If you modify ThermostatQA, you may
 extend this exception to your version of the software, but you are
 not obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version.
 */
package org.thermostat.qa2.framework.services;

import java.io.File;
import java.util.ArrayList;
import java.util.Arrays;
import org.thermostat.qa2.framework.ThermostatQAConfig;
import org.thermostat.qa2.framework.utils.FileUtilities;
import org.thermostat.qa2.framework.utils.ProcessUtilities;

/**
 *
 * @author Zdeněk Žamberský
 */
public class BackupService extends AbstractService {

    String[] files;
    ArrayList<String> backupFiles = new ArrayList();
    String backupDir;
    boolean asRoot = false;

    public BackupService(String file) {
        this(new String[]{file});
    }

    public BackupService(String[] files) {
        this(files, ThermostatQAConfig.backupDir);
    }

    public BackupService(String[] files, String backupDir) {
        this.files = files;
        this.backupDir = backupDir;
    }

    @Override
    public String getServiceName() throws Exception {
        return "Backup service: " + Arrays.toString(files);
    }
    
    public void setRunAsRoot(boolean asRoot){
        this.asRoot = asRoot;
    }

    @Override
    public void startServiceImpl() throws Exception {
        setRunning(true);
        for (String file : files) {
            if (new File(file).exists()) {
                String backupPath = FileUtilities.getUniqueFile(backupDir + File.separator + FileUtilities.getFileName(file));
                if (asRoot) {
                    ProcessUtilities.run("sudo", "-n", "cp", "-arT", "--", file, backupPath);
                } else {
                    ProcessUtilities.run("cp", "-arT", "--", file, backupPath);
                }
                backupFiles.add(backupPath);
            }
        }
    }

    @Override
    public void stopServiceImpl() throws Exception {
        for (int i = 0; i < backupFiles.size(); ++i) {
            if (asRoot) {
                ProcessUtilities.run("sudo", "-n", "rm", "-rf", "--", files[i]);
                ProcessUtilities.run("sudo", "-n", "mv", "--", backupFiles.get(i), files[i]);
            } else {
                ProcessUtilities.run("rm", "-rf", "--", files[i]);
                ProcessUtilities.run("mv", "--", backupFiles.get(i), files[i]);
            }
        }
        setRunning(false);
    }

}
